# Generated by Django 4.2.2 on 2023-06-22 15:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("msgs", "0012_alter_email_object_id_alter_message_object_id_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="email",
            name="service_context",
            field=models.JSONField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="message",
            name="service_context",
            field=models.JSONField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="sms",
            name="service_context",
            field=models.JSONField(blank=True, null=True),
        ),
    ]
