# Generated by Django 4.2.2 on 2023-06-22 13:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("msgs", "0011_auto_20220613_0857"),
    ]

    operations = [
        migrations.AlterField(
            model_name="email",
            name="object_id",
            field=models.CharField(blank=True, max_length=64, null=True),
        ),
        migrations.AlterField(
            model_name="message",
            name="object_id",
            field=models.CharField(blank=True, max_length=64, null=True),
        ),
        migrations.AlterField(
            model_name="sms",
            name="object_id",
            field=models.CharField(blank=True, max_length=64, null=True),
        ),
    ]
