# Generated by Django 3.2.5 on 2021-08-25 12:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('msgs', '0007_auto_20210715_1608'),
    ]

    operations = [
        migrations.AddField(
            model_name='emailtemplate',
            name='external_key',
            field=models.CharField(blank=True, max_length=64, null=True),
        ),
        migrations.AddField(
            model_name='messagetemplate',
            name='external_key',
            field=models.CharField(blank=True, max_length=64, null=True),
        ),
        migrations.AddField(
            model_name='smstemplate',
            name='external_key',
            field=models.CharField(blank=True, max_length=64, null=True),
        ),
        migrations.AlterField(
            model_name='emailtemplate',
            name='key',
            field=models.CharField(max_length=64, unique=True),
        ),
        migrations.AlterField(
            model_name='messagetemplate',
            name='key',
            field=models.CharField(max_length=64, unique=True),
        ),
        migrations.AlterField(
            model_name='smstemplate',
            name='key',
            field=models.CharField(max_length=64, unique=True),
        ),
    ]
