# Generated by Django 5.0.6 on 2024-06-04 06:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('msgs', '0015_email_sender_message_sender_sms_sender_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='email',
            name='error',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='message',
            name='error',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='sms',
            name='error',
            field=models.TextField(blank=True, null=True),
        ),
    ]
