# Generated by Django 4.2.2 on 2023-10-05 12:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("msgs", "0014_email_bcc_emails_email_cc_emails_email_reply_to_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="email",
            name="sender",
            field=models.CharField(blank=True, max_length=256, null=True),
        ),
        migrations.AddField(
            model_name="message",
            name="sender",
            field=models.CharField(blank=True, max_length=256, null=True),
        ),
        migrations.AddField(
            model_name="sms",
            name="sender",
            field=models.CharField(blank=True, max_length=256, null=True),
        ),
        migrations.AlterField(
            model_name="email",
            name="provider_response",
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="email",
            name="reply_to",
            field=models.CharField(blank=True, max_length=256, null=True),
        ),
        migrations.AlterField(
            model_name="message",
            name="provider_response",
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name="sms",
            name="provider_response",
            field=models.TextField(blank=True, null=True),
        ),
    ]
