# Generated by Django 4.2.2 on 2023-07-30 20:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("msgs", "0013_email_service_context_message_service_context_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="email",
            name="bcc_emails",
            field=models.JSONField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="email",
            name="cc_emails",
            field=models.JSONField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name="email",
            name="reply_to",
            field=models.CharField(blank=True, max_length=64, null=True),
        ),
        migrations.AlterField(
            model_name="email",
            name="attachments",
            field=models.ManyToManyField(blank=True, to="msgs.emailattachment"),
        ),
    ]
