# Generated by Django 3.1.3 on 2020-12-01 15:39

import django.contrib.postgres.fields.jsonb
from django.db import migrations, models
import django.db.models.deletion
import django_extensions.db.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Tpl',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('key', models.CharField(max_length=32, unique=True)),
                ('subject_en', models.CharField(default='Subject', max_length=254)),
                ('body_en', models.TextField()),
            ],
        ),
        migrations.CreateModel(
            name='Msg',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', django_extensions.db.fields.CreationDateTimeField(auto_now_add=True, verbose_name='created')),
                ('modified', django_extensions.db.fields.ModificationDateTimeField(auto_now=True, verbose_name='modified')),
                ('recipient', models.CharField(max_length=64)),
                ('context', django.contrib.postgres.fields.jsonb.JSONField(blank=True, null=True)),
                ('status', models.PositiveSmallIntegerField(choices=[(0, 'In queue'), (1, 'Sent'), (2, 'Error')], default=0)),
                ('error', models.CharField(blank=True, max_length=256, null=True)),
                ('tpl', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='msgs.tpl')),
            ],
            options={
                'get_latest_by': 'modified',
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='Email',
            fields=[
            ],
            options={
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('msgs.msg',),
        ),
        migrations.CreateModel(
            name='SMS',
            fields=[
            ],
            options={
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('msgs.msg',),
        ),
    ]
